@@ -116,6 +116,11 @@ VARIABLES = {
     "quality_bits": Variable(
         long_name="Data quality bits", dtype=Dtype.INT, required=[Product.CATEGORIZE]
     ),
+    "beta": Variable(
+        long_name="Attenuated backscatter coefficient",
+        units="sr-1 m-1",
+        required=[Product.CATEGORIZE],
+    ),
     "beta_error": Variable(
         long_name="Error in attenuated backscatter coefficient",
         units="dB",
@@ -350,11 +355,6 @@ VARIABLES = {
         units="m s-1",
         required=[Product.RADAR, Product.CATEGORIZE],
     ),
-    "beta": Variable(
-        long_name="Attenuated backscatter coefficient",
-        units="sr-1 m-1",
-        required=[Product.LIDAR, Product.CATEGORIZE],
-    ),
     "temperature": Variable(
         long_name="Temperature", units="K", required=[Product.MODEL, Product.CATEGORIZE]
     ),
@@ -651,4 +651,71 @@ VARIABLES = {
     "maximum_hail_diameter": Variable(
         long_name="Maximum hail diameter", units="mm", dtype=Dtype.INT
     ),
+    # rv-polarstern specific
+    "beta_1064_raw": Variable(long_name="Attenuated backscatter coefficient", units="sr-1 m-1"),
+    "beta_1064": Variable(long_name="Attenuated backscatter coefficient", units="sr-1 m-1"),
+    "beta_532_raw": Variable(long_name="Attenuated backscatter coefficient", units="sr-1 m-1"),
+    "beta_532": Variable(long_name="Attenuated backscatter coefficient", units="sr-1 m-1"),
+    "beta_355_raw": Variable(long_name="Attenuated backscatter coefficient", units="sr-1 m-1"),
+    "beta_355": Variable(long_name="Attenuated backscatter coefficient", units="sr-1 m-1"),
+    "beta_355_nr": Variable(
+        long_name="Attenuated backscatter coefficient (near range)", units="sr-1 m-1"
+    ),
+    "beta_355_nr_raw": Variable(
+        long_name="Attenuated backscatter coefficient (near range)", units="sr-1 m-1"
+    ),
+    "beta_532_nr": Variable(
+        long_name="Attenuated backscatter coefficient (near range)", units="sr-1 m-1"
+    ),
+    "beta_532_nr_raw": Variable(
+        long_name="Attenuated backscatter coefficient (near range)", units="sr-1 m-1"
+    ),
+    "calibration_factor_1064": Variable(
+        long_name="Attenuated backscatter at 1064 calibration factor",
+    ),
+    "calibration_factor_532": Variable(
+        long_name="Attenuated backscatter at 532 calibration factor",
+    ),
+    "calibration_factor_355": Variable(
+        long_name="Attenuated backscatter at 355 calibration factor",
+    ),
+    "calibration_factor_355_nr": Variable(
+        long_name="Attenuated backscatter at 355 near range calibration factor",
+    ),
+    "calibration_factor_532_nr": Variable(
+        long_name="Attenuated backscatter at 532 near range calibration factor",
+    ),
+    "depolarisation_355_raw": Variable(
+        long_name="Lidar volume linear depolarisation ratio",
+    ),
+    "depolarisation_355": Variable(
+        long_name="Lidar volume linear depolarisation ratio",
+    ),
+    "depolarisation_532_raw": Variable(
+        long_name="Lidar volume linear depolarisation ratio",
+    ),
+    "depolarisation_532": Variable(
+        long_name="Lidar volume linear depolarisation ratio",
+    ),
+    "depolarisation_1064": Variable(
+        long_name="Lidar volume linear depolarisation ratio",
+    ),
+    "depolarisation_1064_raw": Variable(
+        long_name="Lidar volume linear depolarisation ratio",
+    ),
+    "snr_1064": Variable(
+        long_name="Signal-to-Noise Ratio (1064 nm)",
+    ),
+    "snr_532": Variable(
+        long_name="Signal-to-Noise Ratio (532 nm)",
+    ),
+    "snr_355": Variable(
+        long_name="Signal-to-Noise Ratio (355 nm)",
+    ),
+    "snr_532_nr": Variable(
+        long_name="Signal-to-Noise Ratio (532 nm near range)",
+    ),
+    "snr_355_nr": Variable(
+        long_name="Signal-to-Noise Ratio (355 nm near range)",
+    ),
 }
